Welcome to easyadwords's documentation!
=======================================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage

Documentation
=============

.. toctree::
    :maxdepth: 1

    modules/adwords
